@@ -1,5 +1,5 @@
 /*******************************************************************************
- * Copyright (c) 2010, 2015 IBM Corporation and others.
+ * Copyright (c) 2010, 2020 IBM Corporation and others.
  *
  * This program and the accompanying materials
  * are made available under the terms of the Eclipse Public License 2.0
@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     George Suaridze <suag@1c.ru> (1C-Soft LLC) - Bug 560168
  *******************************************************************************/
 
 package org.eclipse.help.internal.base.scope;
@@ -26,7 +27,6 @@ import org.eclipse.core.runtime.Platform;
 import org.eclipse.help.base.AbstractHelpScope;
 import org.eclipse.help.base.IHelpScopeProducer;
 import org.eclipse.help.base.IScopeHandle;
-import org.eclipse.help.internal.base.HelpBasePlugin;
 
 public class ScopeRegistry {
 
@@ -39,17 +39,17 @@ public class ScopeRegistry {
 
 	private static List<IScopeHandle> scopes = null;
 
-	private static ScopeRegistry instance;
-
 	private boolean initialized = false;
 
+	private static class RegistryHolder {
+		static final ScopeRegistry instance = new ScopeRegistry();
+	}
+
 	private ScopeRegistry() {
 	}
 
 	public static ScopeRegistry getInstance() {
-		if (instance == null)
-			instance = new ScopeRegistry();
-		return instance;
+		return RegistryHolder.instance;
 	}
 
 	public AbstractHelpScope getScope(String id) {
@@ -82,8 +82,7 @@ public class ScopeRegistry {
 			try {
 				obj = element.createExecutableExtension("class"); //$NON-NLS-1$
 			} catch (CoreException e) {
-				HelpBasePlugin.logError("Create extension failed:[" //$NON-NLS-1$
-						+ SCOPE_XP_NAME + "].", e); //$NON-NLS-1$
+				Platform.getLog(getClass()).error("Create extension failed:[" + SCOPE_XP_NAME + "].", e); //$NON-NLS-1$ //$NON-NLS-2$
 			}
 			if (obj instanceof AbstractHelpScope) {
 				String id = element.getAttribute("id"); //$NON-NLS-1$
@@ -121,7 +120,7 @@ public class ScopeRegistry {
 				scopes.add(scope);
 		}
 
-		if (scopes.size()==0)
+		if (scopes.isEmpty())
 			return null;
 		if (scopes.size()==1)
 			return scopes.get(0);
@@ -191,7 +190,7 @@ public class ScopeRegistry {
 	 * returning each part of the phrase as a separate element
 	 *
 	 */
-	class ScopePhrase{
+	static class ScopePhrase{
 
 		private String phrase;
 		private int cursor;
@@ -219,14 +218,14 @@ public class ScopeRegistry {
 					return format(next,current);
 				next+=current;
 			}
-			if (next.equals("")) //$NON-NLS-1$
+			if (next.isEmpty())
 				return null;
 			return next;
 		}
 
 		private String format(String next,char current)
 		{
-			if (next.equals("")) //$NON-NLS-1$
+			if (next.isEmpty())
 			{
 				cursor++;
 				return current+""; //$NON-NLS-1$
@@ -241,7 +240,7 @@ public class ScopeRegistry {
 	 * on one Scope, or a union/intersection of scopes.
 	 *
 	 */
-	private class TempScope
+	private static class TempScope
 	{
 		public final static int SELF=0;
 		public final static int UNION=1;
