@@ -119,7 +119,7 @@ public class HelpIndexBuilder {
 	private static HashSet<String> legalLanguages = null;
 	private static HashSet<String> legalCountries = null;
 
-	class PluginIdentifier {
+	static class PluginIdentifier {
 		String id;
 
 		Version version;
@@ -130,7 +130,7 @@ public class HelpIndexBuilder {
 		}
 	}
 
-	class LocaleDir {
+	static class LocaleDir {
 		String locale;
 		String relativePath;
 		ArrayList<File> dirs = new ArrayList<>();
@@ -191,7 +191,7 @@ public class HelpIndexBuilder {
 		}
 	}
 
-	class TocFile {
+	static class TocFile {
 		String href;
 		boolean primary;
 		String extraDir;
@@ -536,7 +536,7 @@ public class HelpIndexBuilder {
 			href = getAttribute(topic, "topic"); //$NON-NLS-1$
 		}
 		if (href != null
-				&& !href.equals("") && !href.startsWith("http://") && !href.startsWith("https://")) { //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+				&& !href.isEmpty() && !href.startsWith("http://") && !href.startsWith("https://")) { //$NON-NLS-1$ //$NON-NLS-2$
 			href = SearchIndex.getIndexableHref(href);
 			if (href != null)
 				hrefs.add(href);
@@ -545,7 +545,7 @@ public class HelpIndexBuilder {
 		for (int i = 0; i < subtopics.getLength(); i++) {
 			Element subtopic = (Element) subtopics.item(i);
 			href = getAttribute(subtopic, "href"); //$NON-NLS-1$
-			if (href != null && !href.equals("") && !href.startsWith("http://") && !href.startsWith("https://")) { //$NON-NLS-1$ //$NON-NLS-2$ //$NON-NLS-3$
+			if (href != null && !href.isEmpty() && !href.startsWith("http://") && !href.startsWith("https://")) { //$NON-NLS-1$ //$NON-NLS-2$
 				href = SearchIndex.getIndexableHref(href);
 				if (href != null)
 					hrefs.add(href);
@@ -672,9 +672,8 @@ public class HelpIndexBuilder {
 				"META-INF/MANIFEST.MF"); //$NON-NLS-1$
 
 		if (OSGiFile.exists()) {
-			try {
-				Manifest OSGiManifest = new Manifest(new FileInputStream(
-						OSGiFile));
+			try (FileInputStream fis = new FileInputStream(OSGiFile)) {
+				Manifest OSGiManifest = new Manifest(fis);
 				Properties headers = manifestToProperties(OSGiManifest
 						.getMainAttributes());
 				String value = headers.get(Constants.BUNDLE_SYMBOLICNAME)
