@@ -15,6 +15,7 @@
 package org.eclipse.help.ui.internal.views;
 
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Set;
@@ -404,7 +405,7 @@ public class ContextHelpPart extends SectionPart implements IHelpPart {
 		if (part != null) {
 			if (searchTerms != null) {
 				if (HelpPlugin.DEBUG_CONTEXT) {
-					System.out.println("Dynamic help - search for " + searchTerms); //$NON-NLS-1$
+					System.out.println("Dynamic help - search for " + Arrays.toString(searchTerms)); //$NON-NLS-1$
 				}
 				part.startSearch(buildSearchExpression(searchTerms), lastContext);
 			}
@@ -423,7 +424,7 @@ public class ContextHelpPart extends SectionPart implements IHelpPart {
 		return buff.length() > 0 ? buff.toString().trim() : null;
 	}
 
-	private class SearchTerms {
+	private static class SearchTerms {
 
 		private List<String> terms = new ArrayList<>();
 		private Set<String> termSet = new HashSet<>();
