@@ -19,6 +19,7 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.net.URL;
 import java.net.URLEncoder;
+import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.List;
 
@@ -112,7 +113,8 @@ public class ParallelSearchServletTest {
 	private Node[] getSearchHitsFromServlet(String phrase)
 			throws Exception {
 		int port = WebappManager.getPort();
-		URL url = new URL("http", "localhost", port, "/help/search?phrase=" + URLEncoder.encode(phrase, "UTF-8"));
+		URL url = new URL("http", "localhost", port,
+				"/help/search?phrase=" + URLEncoder.encode(phrase, StandardCharsets.UTF_8));
 		return makeServletCall(url);
 	}
 
