@@ -10,6 +10,7 @@
  *
  * Contributors:
  *     IBM Corporation - initial API and implementation
+ *     Christoph Läubrich - Bug 552773 - Simplify logging in platform code base
  *******************************************************************************/
 
 package org.eclipse.ui.internal.cheatsheets.composite.views;
@@ -21,15 +22,12 @@ import java.util.HashMap;
 import java.util.Map;
 
 import org.eclipse.core.runtime.FileLocator;
-import org.eclipse.core.runtime.IStatus;
 import org.eclipse.core.runtime.Path;
 import org.eclipse.core.runtime.Platform;
-import org.eclipse.core.runtime.Status;
 import org.eclipse.jface.resource.ImageDescriptor;
 import org.eclipse.osgi.util.NLS;
 import org.eclipse.swt.graphics.Image;
 import org.eclipse.ui.internal.cheatsheets.CheatSheetPlugin;
-import org.eclipse.ui.internal.cheatsheets.ICheatSheetResource;
 import org.eclipse.ui.internal.cheatsheets.Messages;
 import org.eclipse.ui.internal.cheatsheets.registry.CheatSheetRegistryReader;
 import org.eclipse.ui.internal.provisional.cheatsheets.TaskExplorer;
@@ -63,8 +61,7 @@ private static TaskExplorerManager instance;
 				extClass = bundle.loadClass(className);
 			} catch (Exception e) {
 				String message = NLS.bind(Messages.ERROR_LOADING_CLASS, (new Object[] {className}));
-				Status status = new Status(IStatus.ERROR, ICheatSheetResource.CHEAT_SHEET_PLUGIN_ID, IStatus.OK, message, e);
-				CheatSheetPlugin.getPlugin().getLog().log(status);
+				CheatSheetPlugin.getPlugin().getLog().error(message, e);
 			}
 			try {
 				if (extClass != null) {
@@ -73,8 +70,7 @@ private static TaskExplorerManager instance;
 				}
 			} catch (Exception e) {
 				String message = NLS.bind(Messages.ERROR_CREATING_CLASS, (new Object[] {className}));
-				IStatus status = new Status(IStatus.ERROR, ICheatSheetResource.CHEAT_SHEET_PLUGIN_ID, IStatus.OK, message, e);
-				CheatSheetPlugin.getPlugin().getLog().log(status);
+				CheatSheetPlugin.getPlugin().getLog().error(message, e);
 			}
 
 			return explorerInstance;
